#!/bin/env python
from pylab import *
from numpy import *
rc('text', usetex=True)

class Ellipse(Polygon):
   def __init__(self, x0, y0, maj, min, pa, *args, **kwargs):
      if not args:
         args = (0.0, 360.0, 1.0)
      startang, endang, delta = args         
      sinP = sin( pa*pi/180.0 )
      cosP = cos( pa*pi/180.0 )
      phi  = arange( startang, endang+delta, delta, dtype="f" )
      phi *= pi/180.0
      cosA = cos( phi )
      sinA = sin( phi )
      d = (min * cosA)**2 + (maj * sinA)**2
      r = sqrt( (maj**2 * min**2)/d )
      Xell = r * cosA
      Yell = r * sinA
      Xr = Xell * cosP - Yell * sinP + x0
      Yr = Xell * sinP + Yell * cosP + y0
      vertices = zip(Xr,Yr)
      Polygon.__init__(self, vertices, **kwargs)

def Cos(x):
   return cos(pi*x/180.0)

def Sin(x):
   return sin(pi*x/180.0)


axis('equal')
axis([-0.5,1.3,-0.5,1.3])
axis('off')
ax = gca()
ex = 0.4; ey = 0.2
aw = 0.04
c1 = Circle( (0,0), 1.0, fill=False, edgecolor='red' )
c2 = Circle( (0+ex,0+ey), 1.0, fill=False, edgecolor='blue' )
alpha1 = 60.0
x1 = Cos(alpha1)
y1 = Sin(alpha1)
a1 = Arrow( 0.0, 0.0, x1,y1, width=aw )

x2 = x1 + ex
y2 = y1 + ey
a2  = Arrow( x1, y1, ex,ey, width=aw, facecolor="green", edgecolor="green" )
a3  = Arrow( 0,0, x1+ex,y1+ey, width=aw )

dalpha = (x1*x2+y1*y2)/sqrt(x2*x2+y2*y2)
dalpha = arccos(dalpha)*180.0/pi
alpha2 = alpha1-dalpha
x3 = Cos(alpha2)
y3 = Sin(alpha2)
a4 = Arrow( 0,0, x3,y3, width=aw, facecolor="red", edgecolor="red" )
a5 = Arrow( x3,y3, -ex,-ey, width=aw,facecolor="green", edgecolor="green" )
a6 = Arrow( 0,0, x3-ex,y3-ey, width=0.01 )

text( 0.62, 0.62, r"$\vec r_1$", fontsize=16, color="red")
text( 0.812, 0.840, r"$\lambda \vec r_1$", fontsize=16, color="blue" )
text( 0.33, 0.81, r"$\vec r_0$", fontsize=16, color="blue")
text( 0.63, 1.0, r"$-\vec a$", fontsize=16, color="green")
text( 0.06, 0.35, r"$\vec {r'_0}$", fontsize=16, color="black")
text( 0.26,0.64, r"$+\vec a$", fontsize=16, color="green")

ax.add_patch(c1)
ax.add_patch(c2)
ax.add_patch(a1)
ax.add_patch(a2)
ax.add_patch(a3)
ax.add_patch(a4)
ax.add_patch(a5)
ax.add_patch(a6)


"""


ax = gca()
p  = Polygon(((0.1,0.1),(0.5,0.9),(0.9,0.1)))
e  = Ellipse(-0.3, -0.3, 0.5, 0.25, 60.0, 0.0, 360.0, 1.0)
e2 = Ellipse(0.3, 0.3, 0.5, 0.25, -60.0, 0.0, 360.0, 1.0, fill=0)
c  = Circle((0.3, 0.4), radius=0.2, resolution=180, facecolor='magenta')
a  = Arrow( 0.0, 0.0, -0.4, 0.4, width=0.2 )
e.set_facecolor('green')
e.set_edgecolor('red')
e.set_linewidth(3.0)
c.set_alpha(0.7)

ax.add_patch(p)
ax.add_patch(c)
ax.add_patch(e)
ax.add_patch(e2)
ax.add_patch(a)
"""
savefig("etermplot.png")
show()
