from kapteyn import maputils
from matplotlib import pyplot as plt

info = """\nCode shows that a colorbar can be plotted without 
specifying an Axes. The Axes will be created as inset_axes of the
parent Axes object, without changing the parent (e.g. when you use
the AxesDivider solution, it will borrow space at draw time).
The advantage of this method is that after resizing the plot window,
the width or heigth of the colorbar remains in phase with the image
size.\n"""
print(info)

fitsobj = maputils.FITSimage("m101.fits")
fig = plt.figure(figsize=(7,7.5))
frame = fig.add_axes((0.2, 0.25, 0.7, 0.7))

annim = fitsobj.Annotatedimage(cmap="jet", clipmin=8000, frame=frame)
annim.Image()
annim.Graticule()
units = r'$ergs/(sec.cm^2)$'
colbar = annim.Colorbar(fontsize=8, size="4%", orientation='horizontal')
colbar.set_label(label=units, fontsize=14)
annim.plot()
annim.interact_imagecolors()
plt.show()
